@@ -241,12 +241,15 @@ The `rklib` source code and related files and documentation are distributed unde
 
 ### See also
 
-  * [FOODIE](https://github.com/Fortran-FOSS-Programmers/FOODIE)
-  * [FLINT](https://github.com/princemahajan/FLINT)
-  * [DDEABM](https://github.com/jacobwilliams/ddeabm)
-  * [DOP853](https://github.com/jacobwilliams/dop853)
-  * [DVODE](https://github.com/jacobwilliams/dvode)
-  * [libode](https://github.com/markmbaum/libode)
+  * [FOODIE](https://github.com/Fortran-FOSS-Programmers/FOODIE) Fortran Object-Oriented Differential-equations Integration Environment
+  * [FLINT](https://github.com/princemahajan/FLINT) Fortran Library for numerical INTegration of differential equations
+  * [DDEABM](https://github.com/jacobwilliams/ddeabm) Modern Fortran implementation of the DDEABM Adams-Bashforth algorithm
+  * [DOP853](https://github.com/jacobwilliams/dop853) Modern Fortran Edition of Hairer's DOP853 ODE Solver. An explicit Runge-Kutta method of order 8(5,3) for problems y'=f(x,y); with dense output of order 7
+  * [DVODE](https://github.com/jacobwilliams/dvode) Modern Fortran Edition of the DVODE ODE Solver
+  * [ODEPACK](https://github.com/jacobwilliams/odepack) Work in Progress to refactor and modernize the ODEPACK Library
+  * [libode](https://github.com/markmbaum/libode) Easy-to-compile, high-order ODE solvers as C++ classes
+
+
 """
 
 ################################################################################################
@@ -299,7 +302,7 @@ def write_property_file(fixed_or_variable : str, methods : list):
 ################################################################################################
 def write_property_interface_file(fixed_or_variable : str, methods : list):
     """Interfaces for the property methods (creates an include file)"""
-    with open(f'./src/rklib_{fixed_or_variable}_property_interfaces.i90', 'w') as f:
+    with open(f'./src/rklib_{fixed_or_variable}_property_interfaces.inc', 'w') as f:
         for m in methods:
             short_name, long_name, props, order, stages, registers, cfl, reference = m
             f.write(f'pure module function {short_name}_properties(me) result(p)\n')
@@ -311,7 +314,7 @@ def write_property_interface_file(fixed_or_variable : str, methods : list):
 ################################################################################################
 def write_class_file(fixed_or_variable : str, methods : list):
     """Defines the integrator classes (creates an include file)"""
-    with open(f'./src/rklib_{fixed_or_variable}_classes.i90', 'w') as f:
+    with open(f'./src/rklib_{fixed_or_variable}_classes.inc', 'w') as f:
         f.write(f'    ! {fixed_or_variable.capitalize()} step methods:\n\n')
         for m in methods:
             short_name, long_name, props, order, stages, registers, cfl, reference = m
@@ -328,7 +331,7 @@ def write_class_file(fixed_or_variable : str, methods : list):
 
 def write_step_interface_file(fixed_or_variable : str, methods : list):
     """Interfaces for the step methods (creates an include file)"""
-    with open(f'./src/rklib_{fixed_or_variable}_step_interfaces.i90', 'w') as f:
+    with open(f'./src/rklib_{fixed_or_variable}_step_interfaces.inc', 'w') as f:
         f.write(f'    ! {fixed_or_variable} step interfaces\n\n')
         for m in methods:
             short_name, long_name, props, order, stages, registers, cfl, reference = m
@@ -348,7 +351,7 @@ def write_step_interface_file(fixed_or_variable : str, methods : list):
 
 def write_allocate_and_test_file(methods : list):
     """Generate list of method allocations and test calls (creates an include file)"""
-    with open(f'./test/rklib_allocate_and_test.i90', 'w') as f:
+    with open(f'./test/rklib_allocate_and_test.inc', 'w') as f:
         for m in methods:
             f.write(f"    allocate({m[0]}_class :: s); call run_test()\n")
 
